# TODO check that no license information gets lost
{ fetchurl, bash, stdenv, python, go, cmake, vim, vimUtils, perl, ruby, unzip
, which, fetchgit, fetchFromGitHub, fetchhg, fetchzip, llvmPackages, zip
, vim_configurable, vimPlugins, xkb_switch, git, racerdRust, goPackages
, Cocoa ? null
}:

let

inherit (vimUtils.override {inherit vim;}) rtpPath addRtp buildVimPlugin
  buildVimPluginFrom2Nix vimHelpTags;
in

# TL;DR
# Add your plugin to ./vim-plugin-names
# Generate via `vim-plugin-names-to-nix`
# If plugin is complicated then make changes to ./vim2nix/additional-nix-code

# This attrs contains two sections:
# The first contains plugins added manually, the second contains plugins
# generated by call nix#ExportPluginsForNix.
# Documentation & usage see vim-utils.nix.
# attribute names should be the same as used by vim-pi to make dependency
# resolution work
rec {
  # This is not a plugin, it provides bin/vim-open-buffer-with-plugins-derivations
  # which recreates this the following derivations based on ./vim-plugin-names
  pluginnames2nix = vimUtils.pluginnames2Nix {
    name = "vim-plugin-names-to-nix";
    namefiles = [./vim-plugin-names];
  };

  # Section I
  vim-addon-vim2nix = vim2nix;

  vim2nix = buildVimPluginFrom2Nix { # use it to update plugins
    name = "vim2nix";
    src = ./vim2nix;
    dependencies = ["vim-addon-manager"];
  };


  # Section II
  # Update with vimUtils.vimPlugins.pluginnames2Nix command

  # aliasess
  "sourcemap.vim"     = sourcemap;
  Colour_Sampler_Pack = Colour-Sampler-Pack;
  YouCompleteMe       = youcompleteme;
  airline             = vim-airline;
  alternative         = a-vim; # backwards compat, added 2014-10-21
  calendar            = calendar-vim;
  coffee-script       = vim-coffee-script;
  coffeeScript        = coffee-script; # backwards compat, added 2014-10-18
  colors-solarized    = Solarized;
  colorsamplerpack    = Colour_Sampler_Pack;
  command_T           = command-t; # backwards compat, added 2014-10-18
  css_color_5056      = vim-css-color;
  ctrlp               = ctrlp-vim;
  easy-align          = vim-easy-align;
  easymotion          = vim-easymotion;
  eighties            = vim-eighties;
  ghc-mod-vim         = ghcmod;
  gist-vim            = Gist;
  gitgutter           = vim-gitgutter;
  gundo               = gundo-vim;
  Gundo               = gundo-vim; # backwards compat, added 2015-10-03
  haskellConceal      = haskellconceal; # backwards compat, added 2014-10-18
  haskellconceal      = vim-haskellconceal;
  haskellConcealPlus  = vim-haskellConcealPlus;
  hier                = vim-hier;
  hlint-refactor      = hlint-refactor-vim;
  hoogle              = Hoogle;
  ipython             = vim-ipython;
  latex-live-preview  = vim-latex-live-preview;
  multiple-cursors    = vim-multiple-cursors;
  necoGhc             = neco-ghc; # backwards compat, added 2014-10-18
  neocomplete         = neocomplete-vim;
  neosnippet          = neosnippet-vim;
  nerdcommenter       = The_NERD_Commenter;
  nerdtree            = The_NERD_tree;
  quickrun            = vim-quickrun;
  signature           = vim-signature;
  stylish-haskell     = vim-stylish-haskell;
  stylishHaskell      = stylish-haskell; # backwards compat, added 2014-10-18
  supertab            = Supertab;
  syntastic           = Syntastic;
  tabular             = Tabular;
  tagbar              = Tagbar;
  thumbnail           = thumbnail-vim;
  tmux-navigator      = vim-tmux-navigator;
  tmuxNavigator       = tmux-navigator; # backwards compat, added 2014-10-18
  tslime              = tslime-vim;
  vimproc             = vimproc-vim;
  vimshell            = vimshell-vim;
  watchdogs           = vim-watchdogs;
  webapi-vim          = WebAPI;
  wombat256           = wombat256-vim; # backwards compat, added 2015-7-8
  yankring            = YankRing;

  fzf = buildVimPluginFrom2Nix {
    name = goPackages.fzf.name;
    src = "${goPackages.fzf}/share/go/src/github.com/junegunn/fzf";
    dependencies = [];
  };

  # --- generated packages bellow this line ---

  CSApprox = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "CSApprox-2013-07-26";
    src = fetchgit {
      url = "git://github.com/godlygeek/csapprox";
      rev = "7981dac51d8b6776985aa08cb7b5ee98ea7f2ddd";
      sha256 = "17rqhf3gz2al597sy9smk10a7p1bh648659jkl867ay7g7mlgjwc";
    };
    dependencies = [];

  };

  CheckAttach = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "CheckAttach-2015-06-22";
    src = fetchgit {
      url = "git://github.com/chrisbra/CheckAttach";
      rev = "a1d86be7e69b25b41ce1a7fe2d2844330f783b68";
      sha256 = "07rcp8phc0gazls0cassl64gvlxkp0hcc0c32adjw4jsdy11r4mq";
    };
    dependencies = [];

  };

  Gist = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Gist-2015-10-25";
    src = fetchgit {
      url = "git://github.com/mattn/gist-vim";
      rev = "88c331e2e07765090112a396e5e119b39b5aa754";
      sha256 = "1igryyi85bk1pk0jmx4l01skgmjyg1kg1p3ylv0j22d5nibf79qd";
    };
    dependencies = [];

  };

  Hoogle = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Hoogle-2015-12-24";
    src = fetchgit {
      url = "git://github.com/Twinside/vim-hoogle";
      rev = "a5db36f048ac16ab9774fc86f36cd4ae9a444932";
      sha256 = "1855n6dsimbc0brfbmmkx1gszhmgfghm1h1mpi95mq9qzbwkgjri";
    };
    dependencies = [];

  };

  Solarized = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Solarized-2011-05-09";
    src = fetchgit {
      url = "git://github.com/altercation/vim-colors-solarized";
      rev = "528a59f26d12278698bb946f8fb82a63711eec21";
      sha256 = "05d3lmd1shyagvr3jygqghxd3k8a4vp32723fvxdm57fdrlyzcm1";
    };
    dependencies = [];

  };

  Supertab = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Supertab-2016-01-03";
    src = fetchgit {
      url = "git://github.com/ervandew/supertab";
      rev = "66511772a430a5eaad7f7d03dbb02e8f33c4a641";
      sha256 = "065l7vin3gdk4lzcavwl7k850kz93lqhazxn80p2d8rwkx732jgx";
    };
    dependencies = [];

  };

  Syntastic = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Syntastic-2016-05-12";
    src = fetchgit {
      url = "git://github.com/scrooloose/syntastic";
      rev = "c2c6a075113adbfcc4f1ad5b1c0200a0d35ceeb6";
      sha256 = "1b6wc3705n7pj93cf6cv2sazihqw11zq53a7slr646lcdx8r6d7f";
    };
    dependencies = [];

  };

  Tabular = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Tabular-2016-05-04";
    src = fetchgit {
      url = "git://github.com/godlygeek/tabular";
      rev = "00e1e7fcdbc6d753e0bc8043e0d2546fa81bf367";
      sha256 = "0d4n6vggrxvd0jab7yp8wz56dq79g4gjr9fgxfv0q31d3dx1j6js";
    };
    dependencies = [];

  };

  Tagbar = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Tagbar-2015-06-19";
    src = fetchgit {
      url = "git://github.com/majutsushi/tagbar";
      rev = "7b36c46d17d57db34fdb0adac9ba6382d0bb5e66";
      sha256 = "1iqk7y2ckkmzq22jmiyrrxhnzcy8r3kdizwf65l1qbbpfbkp6rrl";
    };
    dependencies = [];

  };

  The_NERD_Commenter = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "The_NERD_Commenter-2015-10-29";
    src = fetchgit {
      url = "git://github.com/scrooloose/nerdcommenter";
      rev = "1f4bfd59920c101a30a74a07b824608a6e65f3fe";
      sha256 = "0gdqmwsyk5ly96d0dp4j7pa0kp6qcl04nzxckh8kxjsbqnphmwaf";
    };
    dependencies = [];

  };

  The_NERD_tree = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "The_NERD_tree-2016-05-11";
    src = fetchgit {
      url = "git://github.com/scrooloose/nerdtree";
      rev = "15445be5fb2559829ac7a1f05af5d713586e8ec9";
      sha256 = "0lpna2w0s85hagx6dpqanicrllmahjnmd0df4cndk0n5nih36x5k";
    };
    dependencies = [];

  };

  UltiSnips = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "UltiSnips-2016-05-08";
    src = fetchgit {
      url = "git://github.com/SirVer/ultisnips";
      rev = "b5edea2e998ae6c62517c7ed3e4c57b652537141";
      sha256 = "03ib1vq5rsj8xsakvdwdwgcwivyr8byx2z3s5rnq0rnwjlnpmqpn";
    };
    dependencies = [];

  };

  VimOutliner = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "VimOutliner-2015-10-01";
    src = fetchgit {
      url = "git://github.com/vimoutliner/vimoutliner";
      rev = "cb41cfd6d636e1243e7e9c46b35fc5cb50588069";
      sha256 = "03w5y57329lnv2rxz0wvnfd1qv6d36zsqgwwvm2j8fvryhs7xbvg";
    };
    dependencies = [];

  };

  WebAPI = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "WebAPI-2016-05-12";
    src = fetchgit {
      url = "git://github.com/mattn/webapi-vim";
      rev = "ca89bd5867e76b154d4eca325b5a9ad6509fccc5";
      sha256 = "14gs351xm474ak4lxava38wrbwd5s26rca387slknncj5x404i65";
    };
    dependencies = [];

  };

  YankRing = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "YankRing";
    src = fetchurl {
      url = "http://www.vim.org/scripts/download_script.php?src_id=23487";
      name = "yankring_190.zip";
      sha256 = "0nnxpsfjp2p9jvs3y5ynnd5s56snz9927zdp9bgmay2jgxfmp0si";
    };
    buildInputs = [ unzip ];
    dependencies = [];
    meta = {
       url = "http://www.vim.org/scripts/script.php?script_id=1234";
    };


  };

  commentary = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "commentary-2016-03-10";
    src = fetchgit {
      url = "git://github.com/tpope/vim-commentary";
      rev = "73e0d9a9d1f51b6cc9dc965f62669194ae851cb1";
      sha256 = "1cyghdlhyyzl366l8r7a2m00pfnga98n6s6a1z00y4rmnnxbk1kk";
    };
    dependencies = [];

  };

  ctrlp-py-matcher = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-py-matcher-2016-01-13";
    src = fetchgit {
      url = "git://github.com/FelikZ/ctrlp-py-matcher";
      rev = "8a803267a741cff3d6147650745f83c8f2125578";
      sha256 = "0d5a7cqjh58l8qgj92s06f2ia83w51g4cic61qxd6sykv9xqiz17";
    };
    dependencies = [];

  };

  ctrlp-z = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-z-2015-10-17";
    src = fetchgit {
      url = "git://github.com/amiorin/ctrlp-z";
      rev = "d1a69ec623ce24b9a30fc8fe3cd468c322b03026";
      sha256 = "16nsj1g8lqmyizlb5ijwhf4dsmh0xv1kwqq6jxvhaf55vfga82yl";
    };
    dependencies = [];

  };

  extradite = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "extradite-2015-09-22";
    src = fetchgit {
      url = "git://github.com/int3/vim-extradite";
      rev = "52326f6d333cdbb9e9c6d6772af87f4f39c00526";
      sha256 = "1wfdw6g16nqwdalq7m7ncnxhzyjcl5c8nsbsnsnr5bgsfgp49xwi";
    };
    dependencies = [];

  };

  fugitive = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "fugitive-2016-05-11";
    src = fetchgit {
      url = "git://github.com/tpope/vim-fugitive";
      rev = "3439f999b138254e4bb56187fc91f91f545b4b12";
      sha256 = "0p6vzfyhy7yvzrfmzyj0f1ccad3fqb3nd86phbl4hwnj8q00qvgw";
    };
    dependencies = [];

  };

  ghcmod = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ghcmod-2016-01-25";
    src = fetchgit {
      url = "git://github.com/eagletmt/ghcmod-vim";
      rev = "815616e8b7d64677d6092e95bc6a3e83d2e035d4";
      sha256 = "1s0wxccmxi0w7ywhwyxggv5n8lcjgh68rhbpp2zrv5n5sg0das73";
    };
    dependencies = [];

  };

  vim-autoformat = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-autoformat-2016-05-13";
    src = fetchgit {
      url = "git://github.com/Chiel92/vim-autoformat";
      rev = "aaf19a31a9fcc53c5158710b69f17fe5ce137698";
      sha256 = "0sps5wzva07g0bc3qgr4l6bh90gl3mrx5913g8q2igvzsfp7g9m3";
    };
    dependencies = [];

  };

  vim-nix = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-nix-2015-12-10";
    src = fetchgit {
      url = "git://github.com/LnL7/vim-nix";
      rev = "f0b7bd4bce5ed0f12fb4d26115c84fb3edcd1e12";
      sha256 = "0r3nffv2yv6vhzhkqx97diqwbcfqvc4j20nrcbmqhaf1bd6xvnsj";
    };
    dependencies = [];

  };

  deoplete-nvim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "deoplete-nvim-2016-05-15";
    src = fetchgit {
      url = "git://github.com/Shougo/deoplete.nvim";
      rev = "22b6244d72aa4d4e015191a88120eceda1064df0";
      sha256 = "1nc6wn3ha9r80p0bpjm05afqddaa5p94cm0a9xfpm6an43g7jxs1";
    };
    dependencies = [];

  };

  Spacegray-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Spacegray-vim-2016-04-24";
    src = fetchgit {
      url = "git://github.com/ajh17/Spacegray.vim";
      rev = "ed44e2a6b0a7cb48ccd1a41c45ab8399e12910ba";
      sha256 = "0m3xm2p1d4ywp20cziz1iiihq4y0ca88hjs4gr48ps0n7h5qf477";
    };
    dependencies = [];

  };

  vim-css-color = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-css-color-2016-04-14";
    src = fetchgit {
      url = "git://github.com/ap/vim-css-color";
      rev = "4421dbac36bedcdd4fc345fd95785cfed518847c";
      sha256 = "11f356rciyxxvdlcijiq5rz2w8vmbcczq32r1fgspaig4pfa933p";
    };
    dependencies = [];

  };

  neomake = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neomake-2016-05-15";
    src = fetchgit {
      url = "git://github.com/benekastah/neomake";
      rev = "10689403d15879859715d7ef42d854c35615854b";
      sha256 = "1fbflq7851x3vqxp2jn0gp1x2cigb9llv3gzhj02mkqc6imhqkcp";
    };
    dependencies = [];

  };

  vim-hdevtools = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-hdevtools-2012-12-29";
    src = fetchgit {
      url = "git://github.com/bitc/vim-hdevtools";
      rev = "474947c52ff9c93dd36f3c49de90bd9a78f0baa1";
      sha256 = "1wwjb9m2l9q75d408jzq9bwv5i376bfgs6vc3ihwwlawcrmhjpxz";
    };
    dependencies = [];

  };

  vim-tmux-navigator = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-tmux-navigator-2016-05-09";
    src = fetchgit {
      url = "git://github.com/christoomey/vim-tmux-navigator";
      rev = "e13914d89e9413cfa449f0c3daff18691356f2d1";
      sha256 = "17cdjj9r13hm5iwnghnfp1bwvz619dv4xg5014962pgkwh9kzdz2";
    };
    dependencies = [];

  };

  spacevim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "spacevim-2016-05-16";
    src = fetchgit {
      url = "git://github.com/ctjhoa/spacevim";
      rev = "c5d03538a8b2f81f2bdb7ca35e589a6a61806ae2";
      sha256 = "0r8jsygm30x8v31lm8al1qr6bh2wvnd9bxj6n8bxv4f87jl8dd2s";
    };
    dependencies = [];

  };

  ctrlp-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "ctrlp-vim-2016-05-01";
    src = fetchgit {
      url = "git://github.com/ctrlpvim/ctrlp.vim";
      rev = "28fce0fb860fe8df0915da1de1fb6e90d6ab2edc";
      sha256 = "1xyxr7m0y2bwiqrb9sj0cjfdc5x474ajqg3bzv4cjv289gvql2qh";
    };
    dependencies = [];

  };

  vim-jade = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jade-2016-02-11";
    src = fetchgit {
      url = "git://github.com/digitaltoad/vim-jade";
      rev = "0a7ec2edaa3f7fbe353f8fd5bf06d3c043d70c81";
      sha256 = "0qlwbywnx6sl2xacdialpmg1d2wmjkdsdklz97k8086glkairs10";
    };
    dependencies = [];

  };

  neco-ghc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neco-ghc-2016-05-07";
    src = fetchgit {
      url = "git://github.com/eagletmt/neco-ghc";
      rev = "b91b30f145d4daaf7e50d083e377bd9fbfdc670b";
      sha256 = "0znz8ym32k2y0ymdr070a9kx35mlalqfv9qlfz252ny348lwkgb8";
    };
    dependencies = [];

  };

  vim-haskellConcealPlus = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-haskellConcealPlus-2016-05-13";
    src = fetchgit {
      url = "git://github.com/enomsg/vim-haskellConcealPlus";
      rev = "81dfb51ff8e471fb1f30659a10daaf1bdd65fb03";
      sha256 = "0vm76gxw62lkyxccrlnn8sblfl3d51svwfra9wfixq4h51jdggyr";
    };
    dependencies = [];

  };

  YUNOcommit-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "YUNOcommit-vim-2014-11-26";
    src = fetchgit {
      url = "git://github.com/esneider/YUNOcommit.vim";
      rev = "981082055a73ef076d7e27477874d2303153a448";
      sha256 = "0mjc7fn405vcx1n7vadl98p5wgm6jxrlbdbkqgjq8f1m1ir81zab";
    };
    dependencies = [];

  };

  vim-go = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-go-2016-05-15";
    src = fetchgit {
      url = "git://github.com/fatih/vim-go";
      rev = "48cc65dfbd3172b989f82c8b67ceb6d88db3c522";
      sha256 = "1zw6jsyzhpl46f37dwslvhg74djl9ngi3h2rzrpgzscpm5wa6h38";
    };
    dependencies = [];

  };

  vim-colorschemes = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-colorschemes-2016-03-18";
    src = fetchgit {
      url = "git://github.com/flazz/vim-colorschemes";
      rev = "189f5182bb70fd35d0f56fee451c3f22a2a80135";
      sha256 = "0wv12f6i07md9c53ygbmyh14zghsr7w9ylkbrfpdjm9z32b0fpwf";
    };
    dependencies = [];

  };

  vim-jsonnet = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jsonnet-2016-05-10";
    src = fetchgit {
      url = "git://github.com/google/vim-jsonnet";
      rev = "9cde81ff3f1afb64f8e6b51e8ebba25b074e26f8";
      sha256 = "0g1xbx8hw03dxpdhdhy4h355lwhfay15294c1i1i7lq3xnb8y6n8";
    };
    dependencies = [];

  };

  vim-leader-guide = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-leader-guide-2016-05-09";
    src = fetchgit {
      url = "git://github.com/hecal3/vim-leader-guide";
      rev = "871f36a1001dd697d679a64a9d58da05ca3f90b8";
      sha256 = "0dflv8nmpxr33q0h0cl8z9ijnbsa895agjbmisz7kq54anwwz763";
    };
    dependencies = [];

  };

  idris-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "idris-vim-2016-01-29";
    src = fetchgit {
      url = "git://github.com/idris-hackers/idris-vim";
      rev = "e1711749f5078f5a9fa53cd15a37627ea9d239f2";
      sha256 = "0mbywk1mwbx3hjzrv7ypp5m800xjj08hxlfmd0piljg41xwkgk5q";
    };
    dependencies = [];

  };

  calendar-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "calendar-vim-2016-05-09";
    src = fetchgit {
      url = "git://github.com/itchyny/calendar.vim";
      rev = "4820ac93f9e8bb0c06c6b8abc1059048f17d1868";
      sha256 = "0zgj73z5c13zgrs3asy3h299ws7gkqqjhl2cqkf1kgssdmyfnbmm";
    };
    dependencies = [];

  };

  lightline-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "lightline-vim-2016-05-14";
    src = fetchgit {
      url = "git://github.com/itchyny/lightline.vim";
      rev = "6de7b19812e3051f739fe05dbd23f040b870c00b";
      sha256 = "1qc95dnmg3zqvizfy1bk2yvw0vkyz547m7a06ccln9pd4hy0kgfk";
    };
    dependencies = [];

  };

  thumbnail-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "thumbnail-vim-2016-03-17";
    src = fetchgit {
      url = "git://github.com/itchyny/thumbnail.vim";
      rev = "4afdc473b47d162610965fa5ed15fa855cca65d4";
      sha256 = "1fcyjw1dvkpijlcm2lbg81am6h188p1bmi3md6wvk48vdj2h56r5";
    };
    dependencies = [];

  };

  vim-ipython = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-ipython-2015-06-23";
    src = fetchgit {
      url = "git://github.com/ivanov/vim-ipython";
      rev = "42499f094b805b90b683afa5009cee99abd0bb75";
      sha256 = "0b9g4ny32772x78k0nnarnm6arm3bj2nxj83sxaqaascvvnw6nbz";
    };
    dependencies = [];

  };

  vim-hier = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-hier-2011-08-27";
    src = fetchgit {
      url = "git://github.com/jceb/vim-hier";
      rev = "0b8c365263551a67404ebd7e528c55e17c1d3de7";
      sha256 = "118pd9sx1bl9vfr89xrf536hfx4l162a43a1qpwpkqxzb9a3ca7n";
    };
    dependencies = [];
    buildInputs = [ vim ];
  };

  vim-orgmode = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-orgmode-2016-05-15";
    src = fetchgit {
      url = "git://github.com/jceb/vim-orgmode";
      rev = "e0d56a6e93798b7a503bb4ab86fec016cd74d466";
      sha256 = "1nm04d5ngbk21c0ykjbflqn9xym1x67rijq7wsgmmm79q0irn25q";
    };
    dependencies = [];

  };

  vim-buffergator = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-buffergator-2016-04-07";
    src = fetchgit {
      url = "git://github.com/jeetsukumaran/vim-buffergator";
      rev = "611966d1ced784d5659c5dc07e984fabd95d917f";
      sha256 = "1fypzqwl89gk024742d59d0ax9wl2xv40bpfmby0cnh1f5hqias3";
    };
    dependencies = [];

  };

  tslime-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tslime-vim-2015-08-14";
    src = fetchgit {
      url = "git://github.com/jgdavey/tslime.vim";
      rev = "4a8091956e331d7b1d4187a2883b720dfec7e9dd";
      sha256 = "09csafrigp1ak566zxvhj71cdr6b6i3fplgncb288r051kw16cg6";
    };
    dependencies = [];

  };

  vim-nerdtree-tabs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-nerdtree-tabs-2014-09-25";
    src = fetchgit {
      url = "git://github.com/jistr/vim-nerdtree-tabs";
      rev = "0decec122e9bb3e9328b01fa20a9650e79cc6ca7";
      sha256 = "1hmxwwxfrk6c6g2mivazpl72s5vw1w5dvl10ivpn52lfw4xgqjxc";
    };
    dependencies = [];

  };

  zenburn = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "zenburn-2015-09-18";
    src = fetchgit {
      url = "git://github.com/jnurmine/zenburn";
      rev = "f7847fb1531b91e2b4bb4aed5db3146f07765179";
      sha256 = "1las12jznf25dkxrjk3s9l70c6wnpjisngmvi83bhw5gvx4c7mq5";
    };
    dependencies = [];

  };

  vim-colorstepper = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-colorstepper-2016-01-28";
    src = fetchgit {
      url = "git://github.com/jonbri/vim-colorstepper";
      rev = "f23ba0d995d41508a2dc9471cf31d3d01a4b5f05";
      sha256 = "05ykxn0gmh8liz0zv5hb8df1ajggxp88izq3825m0yb3ma3k1jqs";
    };
    dependencies = [];

  };

  vim-xdebug = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-xdebug-2012-08-15";
    src = fetchgit {
      url = "git://github.com/joonty/vim-xdebug";
      rev = "a4980fa65f7f159780593ee37c178281691ba2c4";
      sha256 = "1qh18r0sm4gh95sjbi2hnflvxdl4gk00jyy3n7z4i1gnx9ihxjqw";
    };
    dependencies = [];
    postInstall = false;
  };

  fzf-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "fzf-vim-2016-05-17";
    src = fetchgit {
      url = "git://github.com/junegunn/fzf.vim";
      rev = "78c3d254ae29ac877e73e85545c3ae200203f168";
      sha256 = "0lsmn3a9qnjkmw5gzhk2lgr1qg0mi9g0l96vj5v4178432swgsrv";
    };
    dependencies = [];

  };

  limelight-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "limelight-vim-2016-04-12";
    src = fetchgit {
      url = "git://github.com/junegunn/limelight.vim";
      rev = "be8c754eb1cc947521831d0d2e2fb9da5420d57a";
      sha256 = "1nhk4rmpfbp1q9rbihz014v7mk4ai4zpk88k3dmj6ymvmmxj2ayh";
    };
    dependencies = [];

  };

  vim-peekaboo = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-peekaboo-2016-02-29";
    src = fetchgit {
      url = "git://github.com/junegunn/vim-peekaboo";
      rev = "111c4bacbe5216022d56489c366bf4ce985506e9";
      sha256 = "0pblcxb467n4nxkvmb8sl8765nmz17h74hs5dy5dnmaxiy55v0d9";
    };
    dependencies = [];

  };

  vim-eighties = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-eighties-2015-11-02";
    src = fetchgit {
      url = "git://github.com/justincampbell/vim-eighties";
      rev = "62a9719df45fddd0456bf47420fc4768f9c8f5a5";
      sha256 = "108yv5kwcfx7wjn3pqak86vsmcng0ha5s452pl75q3k580f6sf5k";
    };
    dependencies = [];

  };

  latex-box = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "latex-box-2015-06-01";
    src = fetchgit {
      url = "git://github.com/latex-box-team/latex-box";
      rev = "3c2901e12cb78bfb2be58ba4c62a488612550fe1";
      sha256 = "10af319r8y94dnqv8js5fgdr2n482hgkl641hkd3i563159c9wla";
    };
    dependencies = [];

  };

  vim-jinja = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-jinja-2014-06-11";
    src = fetchgit {
      url = "git://github.com/lepture/vim-jinja";
      rev = "4412484b410b15caecd71f2e52758b2a90ea124d";
      sha256 = "1z5ya953nn7233jjjs0ay61x5hfrfddx9xz31grq52cfd0ipy335";
    };
    dependencies = [];

  };

  vimtex = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimtex-2016-05-15";
    src = fetchgit {
      url = "git://github.com/lervag/vimtex";
      rev = "57df1d1686ab339eec93ac51b02993c8c54343c5";
      sha256 = "1lfry5njp6w3gan54xmilczzqryj9n27xdgs72svaljla6c7lbdy";
    };
    dependencies = [];

  };

  vim-easymotion = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-easymotion-2016-05-07";
    src = fetchgit {
      url = "git://github.com/lokaltog/vim-easymotion";
      rev = "5c6f3cd9a713491e6b32752a05c45198aa91540a";
      sha256 = "086zih2mjrv1s596sw09a0vkaijm0ml3v2668n45cpxb04aa11d7";
    };
    dependencies = [];

  };

  vim-xkbswitch = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-xkbswitch-2016-01-31";
    src = fetchgit {
      url = "git://github.com/lyokha/vim-xkbswitch";
      rev = "89fa3fc16251f2e97281d29ade3ee022ba285003";
      sha256 = "16wahaz9d6jyqlvmsn764xqircrwaap3pn4fbgmly7vfmdvq4p8b";
    };
    dependencies = [];
    patchPhase = ''
      substituteInPlace plugin/xkbswitch.vim \
              --replace /usr/local/lib/libxkbswitch.so ${xkb_switch}/lib/libxkbswitch.so
    '';
    buildInputs = [ xkb_switch ];
  };

  vim-startify = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-startify-2016-03-24";
    src = fetchgit {
      url = "git://github.com/mhinz/vim-startify";
      rev = "e74cc71b1b7b33f6df6e8b48ff4b0f587f6bfed9";
      sha256 = "1dimkqzmcw8w10wf75b10bvmskyf9ahxxiyvac4kbr7bipmzz1b3";
    };
    dependencies = [];

  };

  lushtags = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "lushtags-2016-04-26";
    src = fetchgit {
      url = "git://github.com/mkasa/lushtags";
      rev = "641e4163d078e7c3844f2ac82a8153a3ef06484b";
      sha256 = "0fydgz40bfnz6jpmv9bbr3b5bb5vd1514zk9qg3wh12ynpfhqc89";
    };
    dependencies = [];

  };

  hlint-refactor-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "hlint-refactor-vim-2015-12-05";
    src = fetchgit {
      url = "git://github.com/mpickering/hlint-refactor-vim";
      rev = "fffb044ecef854a82c5c2efda252e09044ba03e0";
      sha256 = "0z8d31arfy9aidg1dwj5msnnx799d9r7njkgh51z695w6ayxn6p8";
    };
    dependencies = [];

  };

  vim-stylish-haskell = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-stylish-haskell-2015-05-10";
    src = fetchgit {
      url = "git://github.com/nbouscal/vim-stylish-haskell";
      rev = "c664376ba814de3f87cb7641f90b2c6a9dd53671";
      sha256 = "1xm5ark2mwphznv3xsyzgcldnr52i5jzk1pfqdh0080j07aama8j";
    };
    dependencies = [];

  };

  haskell-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "haskell-vim-2016-05-10";
    src = fetchgit {
      url = "git://github.com/neovimhaskell/haskell-vim";
      rev = "4e87782d1657ac1556c2128ff8dee967953554a1";
      sha256 = "0yyk7ja6ljhn9s55v3d0fsnk0a3y0skcb0wjjspk2nvdj90s4n8z";
    };
    dependencies = [];

  };

  shabadou-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "shabadou-vim-2014-07-27";
    src = fetchgit {
      url = "git://github.com/osyo-manga/shabadou.vim";
      rev = "c5af30bb0c028d53cfd89e00cab636c844034a9a";
      sha256 = "1rjdbjsyhs514cqysrr4cr3qva6v1nixjwdmg3j1jlkjbs5glbir";
    };
    dependencies = [];

  };

  vim-watchdogs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-watchdogs-2016-01-13";
    src = fetchgit {
      url = "git://github.com/osyo-manga/vim-watchdogs";
      rev = "ebcf3df39007aa5d65910f44eb20c9caea9007df";
      sha256 = "0b0sicq8vgil9nm6vnp3k1vlsc6na54cy95pb68w4bj7mscd0q9j";
    };
    dependencies = [];

  };

  vim-racer = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-racer-2016-05-12";
    src = fetchgit {
      url = "git://github.com/racer-rust/vim-racer";
      rev = "6677d268b3bb2770379874eaea275632bf59ff76";
      sha256 = "08g1wbc3cwgkhpyn954n3bb5qyp2zz9lifxzfgndxb0dhmxprf15";
    };
    dependencies = [];

  };

  rust-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "rust-vim-2016-04-12";
    src = fetchgit {
      url = "git://github.com/rust-lang/rust.vim";
      rev = "115d321d383eb96d438466c56cc871fcc1bd0faa";
      sha256 = "1xanv9933vh9rzki6vfzshiav6xrx7025a40v2q9c1l2zx3iz7pb";
    };
    dependencies = [];

  };

  neocomplete-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neocomplete-vim-2016-04-30";
    src = fetchgit {
      url = "git://github.com/shougo/neocomplete.vim";
      rev = "81d39635625730ca43f08762e2908b96e7b7f077";
      sha256 = "0kqyfpz2apj1pz6p4mqzy4256cxmdbd9ra9hiz2f92wymgmnwpcv";
    };
    dependencies = [];

  };

  neosnippet-snippets = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neosnippet-snippets-2016-05-15";
    src = fetchgit {
      url = "git://github.com/shougo/neosnippet-snippets";
      rev = "b068cc47707ecc7d023d75359687b21545bfc341";
      sha256 = "1gy7dn2h1w8bpqr681nqm1kyb9ggxakw25mlhlb3vvb2p8nm553r";
    };
    dependencies = [];

  };

  neosnippet-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "neosnippet-vim-2016-03-30";
    src = fetchgit {
      url = "git://github.com/shougo/neosnippet.vim";
      rev = "ce3c3d209c38a6d87bbf1408d293e179f95e7bb8";
      sha256 = "0lp1p8vwnnwrnhiivzzzd0688vivyxqjgl75piq0xfw24v9ncgcf";
    };
    dependencies = [];

  };

  unite-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "unite-vim-2016-05-15";
    src = fetchgit {
      url = "git://github.com/shougo/unite.vim";
      rev = "5638a2469ecb29eb302aee668981d61da96d301f";
      sha256 = "0jblcwqdq8jgday3khnvari9gijsfvyc0s0c585x0i255rmq414y";
    };
    dependencies = [];

  };

  vimproc-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimproc-vim-2016-04-27";
    src = fetchgit {
      url = "git://github.com/shougo/vimproc.vim";
      rev = "0ff17bc0725cd0323df87664fa02b1436349f667";
      sha256 = "0r5kfj1zl9hld9rx5jdvgmdr30d573ncikily0qcjl90y4rjw3fp";
    };
    dependencies = [];
    buildInputs = [ which ];

    buildPhase = ''
      substituteInPlace autoload/vimproc.vim \
        --replace vimproc_mac.so vimproc_unix.so \
        --replace vimproc_linux64.so vimproc_unix.so \
        --replace vimproc_linux32.so vimproc_unix.so
      make -f make_unix.mak
    '';
  };

  vimshell-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimshell-vim-2016-04-04";
    src = fetchgit {
      url = "git://github.com/shougo/vimshell.vim";
      rev = "bdcd197b701734a743903c7547e9f56842701614";
      sha256 = "04b4kzjg0b8blfqcc21vvn7myq9g7iyn2zy1ypiil64bbch1aw3p";
    };
    dependencies = [ "vimproc-vim" ];
  };

  gundo-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "gundo-vim-2016-01-19";
    src = fetchgit {
      url = "git://github.com/sjl/gundo.vim";
      rev = "e7fe41024ace9047eee610f23311d44fd9d917c0";
      sha256 = "1kdz2qr4z2k2dz6p0jr6y5zwi7n7k1g3m2k52iz03dicvmb5d59h";
    };
    dependencies = [];

  };

  vim-hardtime = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-hardtime-2016-05-03";
    src = fetchgit {
      url = "git://github.com/takac/vim-hardtime";
      rev = "acf59c8df88e1445c145dfca626957d54a1310c3";
      sha256 = "1q7lhj6ll3lycsxqj0ymm7pb6m1sdglgip7wkirjv357yxl7y7kr";
    };
    dependencies = [];

  };

  vim-expand-region = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-expand-region-2013-08-19";
    src = fetchgit {
      url = "git://github.com/terryma/vim-expand-region";
      rev = "966513543de0ddc2d673b5528a056269e7917276";
      sha256 = "0l30wjlk4vxr16f1njnvf8aw9yg9p9jisvcxbcg3znsq5q8ix6zv";
    };
    dependencies = [];

  };

  vimpreviewpandoc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimpreviewpandoc-2016-03-07";
    src = fetchgit {
      url = "git://github.com/tex/vimpreviewpandoc";
      rev = "b109d41ad6478df5ec7f1311950c6efca66f36e4";
      sha256 = "1gx326xarjs3qjygpkrknncad90crjqfx8v6pir4r7k1hl7dfxc4";
    };
    dependencies = [];

  };

  vim-quickrun = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-quickrun-2016-05-10";
    src = fetchgit {
      url = "git://github.com/thinca/vim-quickrun";
      rev = "76f576959cc7d971fcb5ffea25ad72887e3ea035";
      sha256 = "06nbx1ssg95nv3z3i75m134jbihk7iajkf7plfr46i2vmrj602c5";
    };
    dependencies = [];

  };

  molokai = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "molokai-2015-11-11";
    src = fetchgit {
      url = "git://github.com/tomasr/molokai";
      rev = "c67bdfcdb31415aa0ade7f8c003261700a885476";
      sha256 = "1piszjr5kyw43ac1f0jh9z88g824xknshrkchbys9qxlz7pd831s";
    };
    dependencies = [];

  };

  vim-eunuch = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-eunuch-2016-04-16";
    src = fetchgit {
      url = "git://github.com/tpope/vim-eunuch";
      rev = "5ee2b82b565e6c6d80f1cb7735c78f66a159b198";
      sha256 = "1ampwnbi0vpl4g6aj2rax0v902fxk1jyz6azvnnffqzr0b2rnk9b";
    };
    dependencies = [];

  };

  hasksyn = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "hasksyn-2014-09-03";
    src = fetchgit {
      url = "git://github.com/travitch/hasksyn";
      rev = "c434040bf13a17ca20a551223021b3ace7e453b9";
      sha256 = "0c8r72qw7r7sd2cww07x6n2sp5cwkgamjf8khcdh39zcia93b9xi";
    };
    dependencies = [];

  };

  vim-haskellconceal = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-haskellconceal-2014-10-28";
    src = fetchgit {
      url = "git://github.com/twinside/vim-haskellconceal";
      rev = "f73c5dd660b7009a050b131783d7c17b4954e4d9";
      sha256 = "1a1v0m3qj0gian3mp5xynf2ghscr3xaid37b0wi38bb4f2qrigqy";
    };
    dependencies = [];

  };

  youcompleteme = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "youcompleteme-2016-05-11";
    src = fetchgit {
      url = "git://github.com/valloric/youcompleteme";
      rev = "6a81436bd83d174f63c5691e1a9eb24470108942";
      sha256 = "0ir28yk3sgy66y8xxrj9628881lmp6l7bg52zjgycdz57hv85zlg";
    };
    dependencies = [];
    buildInputs = [
      python go cmake
      (if stdenv.isDarwin then llvmPackages.clang else llvmPackages.clang-unwrapped)
      llvmPackages.llvm
    ] ++ stdenv.lib.optional stdenv.isDarwin Cocoa;

    propogatedBuildInputs = [
      racerdRust
    ];

    buildPhase = ''
      patchShebangs .
      substituteInPlace plugin/youcompleteme.vim \
        --replace "'ycm_path_to_python_interpreter', '''" "'ycm_path_to_python_interpreter', '${python}/bin/python'"

      mkdir build
      pushd build
      cmake -G "Unix Makefiles" . ../third_party/ycmd/cpp -DPYTHON_LIBRARIES:PATH=${python}/lib/libpython2.7.so -DPYTHON_INCLUDE_DIR:PATH=${python}/include/python2.7 -DUSE_CLANG_COMPLETER=ON -DUSE_SYSTEM_LIBCLANG=ON
      make ycm_core -j''${NIX_BUILD_CORES} -l''${NIX_BUILD_CORES}}
      ${python}/bin/python ../third_party/ycmd/build.py --gocode-completer --clang-completer --system-libclang
      popd
    '';

    meta = {
      description = "Fastest non utf-8 aware word and C completion engine for Vim";
      homepage = http://github.com/Valloric/YouCompleteMe;
      license = stdenv.lib.licenses.gpl3;
      maintainers = with stdenv.lib.maintainers; [marcweber jagajaga];
      platforms = stdenv.lib.platforms.unix;
    };
  };

  vim-airline-themes = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-airline-themes-2016-05-14";
    src = fetchgit {
      url = "git://github.com/vim-airline/vim-airline-themes";
      rev = "8bf1961e3b50551956fe2703bdfca1eb84ba1daf";
      sha256 = "1ifvg5pmy8g8pcwvx6pnlym2v6szaziliqvl46da8g7g3mxmd4zb";
    };
    dependencies = [];

  };

  vim-pandoc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-pandoc-2016-05-03";
    src = fetchgit {
      url = "git://github.com/vim-pandoc/vim-pandoc";
      rev = "b32791d3cfc999344a9acf22738b41e8ab21aec7";
      sha256 = "1lvq9767ng8156l5946z44sw2s19mb70hn7afxkdsk9771agd365";
    };
    dependencies = [];

  };

  vim-pandoc-after = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-pandoc-after-2015-06-01";
    src = fetchgit {
      url = "git://github.com/vim-pandoc/vim-pandoc-after";
      rev = "4377665e5c98f29ea838deb3b942200b8dd096ef";
      sha256 = "1di82bgi7sjn7lmma7g9zbdraamsy9c6g7ms6jgglfvynbbvmgg0";
    };
    dependencies = [];

  };

  vim-pandoc-syntax = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-pandoc-syntax-2016-03-20";
    src = fetchgit {
      url = "git://github.com/vim-pandoc/vim-pandoc-syntax";
      rev = "a35e9ce28bae85b1ce5d4f817882a8d78efcd6be";
      sha256 = "1d3yw2v9giw2nyk4yb8qdav42wki81g8nzn3dz3rzb6dqq1k3skv";
    };
    dependencies = [];

  };

  Colour-Sampler-Pack = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "Colour-Sampler-Pack-2012-11-29";
    src = fetchgit {
      url = "git://github.com/vim-scripts/Colour-Sampler-Pack";
      rev = "05cded87b2ef29aaa9e930230bb88e23abff4441";
      sha256 = "03v2r18sfgs0xbgy9p56pxfdg0lsk6m7wyr5hw63wm1nzpwiipg3";
    };
    dependencies = [];

  };

  a-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "a-vim-2010-11-06";
    src = fetchgit {
      url = "git://github.com/vim-scripts/a.vim";
      rev = "2cbe946206ec622d9d8cf2c99317f204c4d41885";
      sha256 = "0h62v9z5bh9xmaq22pqdb3z79i84a5rknqm68mjpy7nq7s3q42fa";
    };
    dependencies = [];

  };

  align = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "align-2012-08-07";
    src = fetchgit {
      url = "git://github.com/vim-scripts/align";
      rev = "787662fe90cd057942bc5b682fd70c87e1a9dd77";
      sha256 = "0acacr572kfh7jvavbw61q5pkwrpi1albgancma063rpax1pddgp";
    };
    dependencies = [];

  };

  changeColorScheme-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "changeColorScheme-vim-2010-10-17";
    src = fetchgit {
      url = "git://github.com/vim-scripts/changeColorScheme.vim";
      rev = "b041d49f828629d72f2232531a230d1ec5de2405";
      sha256 = "0pybhsg9k9252d4ifdc4gsar8lkmfzbvs6xkzqq1m6f35l9wqk09";
    };
    dependencies = [];

  };

  random-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "random-vim-2010-10-17";
    src = fetchgit {
      url = "git://github.com/vim-scripts/random.vim";
      rev = "b2d85eb24a38074eab37a5acf2a295e1f2ad8989";
      sha256 = "1lzy2cq4jcrsqyxlnbnd0y6j4mabm09bi7q22lf6vinqlb84w7sp";
    };
    dependencies = [];

  };

  tabmerge = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tabmerge-2010-10-17";
    src = fetchgit {
      url = "git://github.com/vim-scripts/tabmerge";
      rev = "074e5f06f26e7108a0570071a0f938a821768c06";
      sha256 = "0prkyza1n49cdaslcr57w8zv15vw78mlqbzib2xipmawzjq02idq";
    };
    dependencies = [];

  };

  wombat256-vim = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "wombat256-vim-2010-10-17";
    src = fetchgit {
      url = "git://github.com/vim-scripts/wombat256.vim";
      rev = "8734ba45dcf5e38c4d2686b35c94f9fcb30427e2";
      sha256 = "01fdvfwdfqn5xi88lfanb4lb6jmn1ma6wq6d9jj2x7qamdbpvsrg";
    };
    dependencies = [];

  };

  vim-wakatime = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-wakatime-2016-04-29";
    src = fetchgit {
      url = "git://github.com/wakatime/vim-wakatime";
      rev = "2d30996a1622a7f2cd9bf55cf9078d4301648f4c";
      sha256 = "0mkj6bxxjdyi7dd52nfk881ayjym5rqa5r4zjcra9lhbh0fcdhfk";
    };
    dependencies = [];
    buildInputs = [ python ];
  };

  command-t = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "command-t-2016-03-12";
    src = fetchgit {
      url = "git://github.com/wincent/command-t";
      rev = "2d80b2e65cd690dd17c66fb52e5f9fb09700b1e7";
      sha256 = "1ndzjsrf2nz7gaq6q58p4pna82a4zbirclyjkgzg6a58qinhm3pi";
    };
    dependencies = [];
    buildInputs = [ perl ruby ];
    buildPhase = ''
      pushd ruby/command-t
      ruby extconf.rb
      make
      popd
    '';
  };

  goyo = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "goyo-2016-04-03";
    src = fetchgit {
      url = "git://github.com/junegunn/goyo.vim";
      rev = "8e8f1d45b61e1fce7f84ee061c38f9e033e86ff9";
      sha256 = "0q3in448s99df4dls4vlfsnh15q9rargsb68axj4z5z0jdkncpwi";
    };
    dependencies = [];

  };

  matchit-zip = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "matchit-zip";
    src = fetchurl {
      url = "http://www.vim.org/scripts/download_script.php?src_id=8196";
      name = "matchit.zip";
      sha256 = "1bbm8j1bhb70kagwdimwy9vcvlrz9ax5bk2a7wrmn4cy87f9xj4l";
    };
    buildInputs = [ unzip ];
    dependencies = [];
    meta = {
       url = "http://www.vim.org/scripts/script.php?script_id=39";
    };

    unpackPhase = ''
      (
       sourceRoot=d
       mkdir $sourceRoot; cd $sourceRoot;
       unzip $src
      )
    '';
  };

  pathogen = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "pathogen-2016-01-26";
    src = fetchgit {
      url = "git://github.com/tpope/vim-pathogen";
      rev = "8c91196cfd9c8fe619f35fac6f2ac81be10677f8";
      sha256 = "17d1903spczg2rk0qzg94vvq41dwhmnxwajqgzcx4lmf606cfspi";
    };
    dependencies = [];

  };

  quickfixstatus = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "quickfixstatus-2011-09-02";
    src = fetchgit {
      url = "git://github.com/dannyob/quickfixstatus";
      rev = "fd3875b914fc51bbefefa8c4995588c088163053";
      sha256 = "16vxhvyxq51y7wnx0c1fmdi2yb6kfr1pxijq65gxj8qwvbak2s3v";
    };
    dependencies = [];

  };

  rainbow_parentheses = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "rainbow_parentheses-2013-03-04";
    src = fetchgit {
      url = "git://github.com/kien/rainbow_parentheses.vim";
      rev = "eb8baa5428bde10ecc1cb14eed1d6e16f5f24695";
      sha256 = "1qw84imlhq4654mxazj7j3sp5g1j3yjxi496i08iix06dm15m5s7";
    };
    dependencies = [];

  };

  sensible = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "sensible-2016-03-18";
    src = fetchgit {
      url = "git://github.com/tpope/vim-sensible";
      rev = "9e91be7e0fb42949831fe3161ef583363648aa58";
      sha256 = "1g1l3v33g9229r4g4kcx8m1yrh397yf3fn6bxis57n3lg6lmb6wm";
    };
    dependencies = [];

  };

  sleuth = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "sleuth-2015-06-07";
    src = fetchgit {
      url = "git://github.com/tpope/vim-sleuth";
      rev = "a17462708aa40a7fc0afd4effa559087d8a2c908";
      sha256 = "09b01ywp0yd3lajs7gzv17qvjwbffdh6k014ws92b50cwv2vgx3j";
    };
    dependencies = [];

  };

  snipmate = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "snipmate-2016-04-04";
    src = fetchgit {
      url = "git://github.com/garbas/vim-snipmate";
      rev = "66555c2a86ba2136459190c06aa2c0f25ad38bb3";
      sha256 = "01dnscgnkjy8q5ajnxsaxi1zn97v1fbhr4q5sjdqazdis9zxlqq2";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  sourcemap = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "sourcemap-2012-09-19";
    src = fetchgit {
      url = "git://github.com/chikatoike/sourcemap.vim";
      rev = "0dd82d40faea2fdb0771067f46c01deb41610ba1";
      sha256 = "1gcgnynallz420911fdfm0ccbv3zs78p69nnh2ls1r4vlfp7g350";
    };
    dependencies = [];

  };

  surround = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "surround-2015-08-07";
    src = fetchgit {
      url = "git://github.com/tpope/vim-surround";
      rev = "2d05440ad23f97a7874ebd9b5de3a0e65d25d85c";
      sha256 = "0l5kvn2b1v2h90c02ymgsv88p89d0hzsbr6zwf0p2x2f72xjqdz5";
    };
    dependencies = [];

  };

  table-mode = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "table-mode-2016-05-08";
    src = fetchgit {
      url = "git://github.com/dhruvasagar/vim-table-mode";
      rev = "b613e39bd08ecebdb9b18100dae518050f496048";
      sha256 = "0vqiqph6y1dcfhy5xwh3ksafdzhrinpdppvjvw51xhy8i9ycznf6";
    };
    dependencies = [];

  };

  taglist = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "taglist";
    src = fetchurl {
      url = "http://www.vim.org/scripts/download_script.php?src_id=19574";
      name = "taglist_46.zip";
      sha256 = "18cbv462vwg7vip2p99qlahm99hswav96cj4ki227kyi05q2lkjj";
    };
    buildInputs = [ unzip ];
    dependencies = [];
    meta = {
       url = "http://www.vim.org/scripts/script.php?script_id=273";
    };

    setSourceRoot = ''
      export sourceRoot=taglist
      mkdir taglist
      mv doc taglist
      mv plugin taglist
    '';
  };

  tlib = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "tlib-2016-04-06";
    src = fetchgit {
      url = "git://github.com/tomtom/tlib_vim";
      rev = "34b13299b5da7ad66ea387027d458bd54127687c";
      sha256 = "18jhq6m25qv0cfm5iyxi268x1cww6xi5p4hx4c48fsq919bk6k8f";
    };
    dependencies = [];

  };

  undotree = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "undotree-2016-05-08";
    src = fetchgit {
      url = "git://github.com/mbbill/undotree";
      rev = "0917446af029a055a34f12bf668ea0d561e97037";
      sha256 = "0v174icbhgvyddqg1psws3fyian5pwn4cki7skwlsxp6ahl49kal";
    };
    dependencies = [];

  };

  vim-addon-actions = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-actions-2014-09-22";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-actions";
      rev = "a5d20500fb8812958540cf17862bd73e7af64936";
      sha256 = "10v3vxgrlfdd34s5kvh4si985gpygv804fygdwy27rr93xxfphyj";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  vim-addon-async = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-async-2013-10-18";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-async";
      rev = "dadc96e188f1cdacbac62129eb29a1eacfed792c";
      sha256 = "01sxg88578drmwxpphpj7r7mb7l0wfly4509s85r99cc3bi43y97";
    };
    dependencies = ["vim-addon-signs"];

  };

  vim-addon-background-cmd = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-background-cmd-2015-12-11";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-background-cmd";
      rev = "abf2abf339652d2bc79da81f9d131edfe2755f5a";
      sha256 = "080wfsid1iq5b9lqapg0wis5642c69sf9nh9rhs79qapl6x3w8h6";
    };
    dependencies = ["vim-addon-mw-utils"];

  };

  vim-addon-commenting = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-commenting-2013-06-10";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-commenting";
      rev = "b7cf748ac1c9bf555cbd347589e3b7196030d20b";
      sha256 = "0glvpq7i8s9jdi6lvpl8hpyd7mrhq14kdkn94i51n2lzcvvdbmsa";
    };
    dependencies = [];

  };

  vim-addon-completion = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-completion-2015-02-10";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-completion";
      rev = "021c449a5ce1ce4ac0af5955e05b0279c1cc0e75";
      sha256 = "1sm00gs0h96kh7h64gjkyniw07495vqylh157m2f9xzd953lg6ln";
    };
    dependencies = ["tlib"];

  };

  vim-addon-errorformats = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-errorformats-2014-11-05";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-errorformats";
      rev = "dcbb203ad5f56e47e75fdee35bc92e2ba69e1d28";
      sha256 = "159zqm69fxbxcv3b2y99g57bf20qrzsijcvb5rzy2njxah3049m1";
    };
    dependencies = [];

  };

  vim-addon-goto-thing-at-cursor = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-goto-thing-at-cursor-2012-01-11";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-goto-thing-at-cursor";
      rev = "f052e094bdb351829bf72ae3435af9042e09a6e4";
      sha256 = "1skq43y7laq2ric7bqh9abx9mxix5k6xzcs4qnwhsqwskp4qlr9l";
    };
    dependencies = ["tlib"];

  };

  vim-addon-local-vimrc = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-local-vimrc-2015-03-19";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-local-vimrc";
      rev = "6a27f95b35befa70cd0d049329cd0920566c764b";
      sha256 = "0n8lwl1gyak149p7jpgm0qbmfj8hcg8hirx3dxdhizw0yc47ws7h";
    };
    dependencies = [];

  };

  vim-addon-manager = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-manager-2016-02-07";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-manager";
      rev = "872f9302cf0eb8e9cb6259ea4f329d2265f9e32d";
      sha256 = "0rl6sy1gfjsfr1hg2ilhhxppifvjfqn815kh27b3ikcy82rp7sb0";
    };
    dependencies = [];
    buildInputs = stdenv.lib.optional stdenv.isDarwin Cocoa;
  };

  vim-addon-mru = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-mru-2013-08-08";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-mru";
      rev = "e41e39bd9d1bf78ccfd8d5e1bc05ae5e1026c2bb";
      sha256 = "0q6rxr9nrp63kidr3m3c2z5sda4g813pzshg0scxkjr8dxwhzdqm";
    };
    dependencies = ["vim-addon-other" "vim-addon-mw-utils"];

  };

  vim-addon-mw-utils = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-mw-utils-2012-11-05";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-mw-utils";
      rev = "0c5612fa31ee434ba055e21c76f456244b3b5109";
      sha256 = "075r4a73vv6hcrsfznac32nicdk0x7lvxx4fwmii03q5b4dns6sf";
    };
    dependencies = [];

  };

  vim-addon-nix = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-nix-2015-03-10";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-nix";
      rev = "2aed79ba5d8c5e6abd102de77e55e242f61b17f1";
      sha256 = "1qipxzn79nbmjzppa0r59796r56xz5g88jm66fjpqndndhn6wchf";
    };
    dependencies = ["vim-addon-completion" "vim-addon-goto-thing-at-cursor" "vim-addon-errorformats" "vim-addon-actions" "vim-addon-mw-utils" "tlib"];

  };

  vim-addon-other = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-other-2014-07-15";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-other";
      rev = "f78720c9cb5bf871cabb13c7cbf94378dbf0163b";
      sha256 = "06sdjnyp2hqs0kia2hzflyxwiwpp14mkrhhm4l3k2q2pnzj2gw23";
    };
    dependencies = ["vim-addon-actions" "vim-addon-mw-utils"];

  };

  vim-addon-php-manual = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-php-manual-2015-01-01";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-php-manual";
      rev = "5f9810dd1f6e9f36a45f637ae6260ccff09256ff";
      sha256 = "1kc67f12wccqdza069b75lpcbqp4kv4r23i4mfz0ihwif5mfnhir";
    };
    dependencies = [];

  };

  vim-addon-signs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-signs-2013-04-19";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-signs";
      rev = "17a49f293d18174ff09d1bfff5ba86e8eee8e8ae";
      sha256 = "1f4gk984760cbkkwl9isqwab63ghny61h18nfh313maqwwr3mh59";
    };
    dependencies = [];

  };

  vim-addon-sql = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-sql-2014-01-18";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-sql";
      rev = "05b8a0c211f1ae4c515c64e91dec555cdf20d90b";
      sha256 = "1hjpx5s1vn8v7y73gis408jdy8vjivhag2ycp8lk5870jkk4lcx1";
    };
    dependencies = ["vim-addon-completion" "vim-addon-background-cmd" "tlib"];

  };

  vim-addon-syntax-checker = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-syntax-checker-2013-07-12";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-syntax-checker";
      rev = "8eb7217e636ca717d4de5cd03cc0180c5b66ae77";
      sha256 = "0gcvb922w4jsi203ygbnij9xhmgc6knj9b3ivw3m0fv5ckk4iw5f";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  vim-addon-toggle-buffer = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-toggle-buffer-2012-01-13";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-toggle-buffer";
      rev = "a1b38b9c5709cba666ed2d84ef06548f675c6b0b";
      sha256 = "0mb0vyr5rr0ywk26l9cwcplpfzsqdwv49d2nzdx1g685zvn6c8b7";
    };
    dependencies = ["vim-addon-mw-utils" "tlib"];

  };

  vim-addon-xdebug = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-addon-xdebug-2014-08-29";
    src = fetchgit {
      url = "git://github.com/MarcWeber/vim-addon-xdebug";
      rev = "45f26407305b4ce6f8f5f37d2b5e6e4354104172";
      sha256 = "1vv4jha79sw8yxzl9aygr44khqi8yrmz9ysvs95wjwk7yg5g4yqa";
    };
    dependencies = ["WebAPI" "vim-addon-mw-utils" "vim-addon-signs" "vim-addon-async"];

  };

  vim-airline = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-airline-2016-05-15";
    src = fetchgit {
      url = "git://github.com/vim-airline/vim-airline";
      rev = "70c16f4c46f11395bbbc30b2f0a6822669e7df87";
      sha256 = "1ib3rs0ysz41dxk4fmzjrha005adrrlya5bnb8cv1p1ny7ipny1d";
    };
    dependencies = [];

  };

  vim-closetag = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-closetag-2016-04-21";
    src = fetchgit {
      url = "git://github.com/alvan/vim-closetag";
      rev = "26e41a5b0c3752d5300506a49120d9dff19d8323";
      sha256 = "0c8x25hb912jmhf5jpfll08937wr2yls28i9divldm9jkmxvcx2k";
    };
    dependencies = [];

  };

  vim-coffee-script = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-coffee-script-2015-04-20";
    src = fetchgit {
      url = "git://github.com/kchmck/vim-coffee-script";
      rev = "32fe889b8cafd3a4921ef8e6485156453ff58c42";
      sha256 = "14464xyjiw58n785xrkyd5qrinz2gb0p4yhxh6b9r5698qjjn5np";
    };
    dependencies = [];

  };

  vim-easy-align = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-easy-align-2016-03-06";
    src = fetchgit {
      url = "git://github.com/junegunn/vim-easy-align";
      rev = "0cb6b98fc155717b0a56c110551ac57d1d951ddb";
      sha256 = "089c4grk24albishgxdskb1zsvxbzlp2yq1baf0vy6cryxwm8ykq";
    };
    dependencies = [];

  };

  vim-gista = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-gista-2016-04-11";
    src = fetchgit {
      url = "git://github.com/lambdalisue/vim-gista";
      rev = "7ff4d24f242d406ff71d9a65691357aee80f37f7";
      sha256 = "0hm4lnf2mxvdvc13b67cwvyp7griir5lpacnb1sgjx4dxr0w4fzz";
    };
    dependencies = [];

  };

  vim-gitgutter = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-gitgutter-2016-05-13";
    src = fetchgit {
      url = "git://github.com/airblade/vim-gitgutter";
      rev = "cae4f72aa1290c353aa8d0898cac0781ef2ee538";
      sha256 = "0kx117v92pglm72m52p6d2pqa1gsnzy476l7ai1c23jk696pl9vq";
    };
    dependencies = [];

  };

  vim-iced-coffee-script = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-iced-coffee-script-2013-12-27";
    src = fetchgit {
      url = "git://github.com/noc7c9/vim-iced-coffee-script";
      rev = "e42e0775fa4b1f8840c55cd36ac3d1cedbc1dea2";
      sha256 = "14yfirny359rlrr082il2ys3hxiyrbbk794rdxrs2lasjy8rb1f7";
    };
    dependencies = [];

  };

  vim-latex-live-preview = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-latex-live-preview-2016-03-16";
    src = fetchgit {
      url = "git://github.com/xuhdev/vim-latex-live-preview";
      rev = "99501642c1dd3f703ac6301ae13469f4990b7a06";
      sha256 = "0dkm3v1jqi8aq0jfpa6fdwgbfbwidc32ci1y9vhqb1prs15qrqfl";
    };
    dependencies = [];

  };

  vim-multiple-cursors = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-multiple-cursors-2016-04-11";
    src = fetchgit {
      url = "git://github.com/terryma/vim-multiple-cursors";
      rev = "25b567baf712a7e9bc8f3c9ca816bd579363109b";
      sha256 = "1jvg5i76k58sz56z615pb7s7gg7jn0dpwf7rr76v22v4zpyij70h";
    };
    dependencies = [];

  };

  vim-signature = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-signature-2016-04-10";
    src = fetchgit {
      url = "git://github.com/kshenoy/vim-signature";
      rev = "31028e7a0d015b04a51e721af155fd11d1b6ac76";
      sha256 = "1f78ipkfnhmlhw88ii6rqxwfm7qpdc1c8v2716il240bk08khkff";
    };
    dependencies = [];

  };

  vim-signify = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-signify-2016-04-08";
    src = fetchgit {
      url = "git://github.com/mhinz/vim-signify";
      rev = "37376d9970294063b2ba9594204d50cfa181ebb6";
      sha256 = "0ih09i0smn768fkbzbjpfzsjfsm4w653ghaykzcn4hbail67nx84";
    };
    dependencies = [];

  };

  vim-snippets = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-snippets-2016-05-16";
    src = fetchgit {
      url = "git://github.com/honza/vim-snippets";
      rev = "a9b920b478e2c92bb8ce699c27835013a2cc25fb";
      sha256 = "1msi4kvs7zgyi6l9jf0w462kw3lfsxb4bg7i3vrd16zcr5n742mj";
    };
    dependencies = [];

  };

  vim-webdevicons = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim-webdevicons-2016-04-17";
    src = fetchgit {
      url = "git://github.com/ryanoasis/vim-devicons";
      rev = "ad5d6d7f9fdf741a1e0d45b2bebab1d0116e1158";
      sha256 = "039asq5ggbpjc3g8xnd7bgk2szqqgmdh5xa7xhr8yfag26mal1ja";
    };
    dependencies = [];

  };

  vim2hs = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vim2hs-2014-04-16";
    src = fetchgit {
      url = "git://github.com/dag/vim2hs";
      rev = "f2afd55704bfe0a2d66e6b270d247e9b8a7b1664";
      sha256 = "1c75nxk1vk8hq514wx1zm9i5d3qdpd65mv4v4gr50kmvjn2waps8";
    };
    dependencies = [];

  };

  vimwiki = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vimwiki-2016-04-25";
    src = fetchgit {
      url = "git://github.com/vimwiki/vimwiki";
      rev = "f56700932967f09ea6faa0bad60367b0d6b19a0d";
      sha256 = "1x176z40653nqp4rgla298dazwyh3rm95k4d4v4qs5hka14b2jfg";
    };
    dependencies = [];

  };

  vinegar = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vinegar-2016-01-30";
    src = fetchgit {
      url = "git://github.com/tpope/vim-vinegar";
      rev = "75fc3824bc09053f22735d6726c5cfd614c15642";
      sha256 = "19jl854wylmfdr9k4bfyffkz8bl4vpx1znnxzx0qj7cz2s3i9z0r";
    };
    dependencies = [];

  };

  vundle = buildVimPluginFrom2Nix { # created by nix#NixDerivation
    name = "vundle-2016-02-26";
    src = fetchgit {
      url = "git://github.com/gmarik/vundle";
      rev = "4984767509e3d05ca051e253c8a8b37de784be45";
      sha256 = "0n2k3ip81yfx00ch45nqiwayhz8qxmwg5s34a4k5snapzcxcm2fn";
    };
    dependencies = [];

  };

}
